/*
 * $Id: filter.h,v 1.10 2001/04/16 22:54:35 laik Exp $
 *
 * This file contains information about the simulation routines.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __FILTER_H__
#define __FILTER_H__

#include <stdio.h>

#include "kl_statistics.h"
#include "kl_statistics_kernel.h"
#include "kl_buffered_output.h"

#include "nettimer.h"

struct Filter;
typedef struct Filter Filter;

/*
 * Identifies the order of metrics in a sample.
 */
typedef enum {
    FilterMetricMeasuredBW,
    FilterMetricPotentialBW,
    FilterMetricArrivalTime,
    FilterMetricLast,
} FilterMetric;

/*
 * Encapsulates the results of the filtering.
 */
typedef struct FilterResult {
    double bw;
    double pbw;
    double weight;
    double kernel;
    double error;
    unsigned int num_kernels;
    unsigned int num_samples;
} FilterResult;

/*
 * Encapsulates the specifications for how filtering should be done.
 */
typedef struct FilterDef {
    unsigned int num_sets;                     /* Number of sample sets. */
    unsigned int window_size;                  /* Max number of samples */
    double kernel_bound_ratio;                 /* Kernel width ratio */
    double *kernel_resolution;                 /* Kernel resolution */
    KLStatisticsKernelFunction kernel_function;/* Kernel function */
    unsigned int eviction_memory_size;         /* Size of eviction memory */
    unsigned int eviction_sample_size;         /* Size of eviction sample */
    double kernel_weight;                      /* */
    double pbw_weight;                         /* */
    double mbw_weight;                         /* */
    double age_weight;
    KLBufferedOutput *sample_log;              /* Write samples this log */
} FilterDef;

Filter *
filter_new(FilterDef *filter_def);

void
filter_delete(struct Filter *filter);

void
filter_new_metric_set(Filter *filter, int set_index, int correlate);

void
filter_add_sample(Filter *filter, int set_index, const double *sample);

unsigned int 
filter_get_result(Filter *filter, int set_index, FilterResult *result);

void
filter_verify(Filter *filter);

#endif
