/*
 * $Id: flow_calc.h,v 1.8 2001/04/02 07:17:12 laik Exp $
 *
 * This file contains interfaces and data structures for the flow_calc module.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef __FLOW_CALC_H__
#define __FLOW_CALC_H__

#include <sys/types.h>

#include "dpcap_flow.h"
#include "kl_event.h"
#include "kl_list.h"
#include "kl_buffered_output.h"

#include "filter.h"
#include "calc.h"

struct FlowCalcSet;
typedef struct FlowCalcSet FlowCalcSet;

struct FlowCalcFlow;
typedef struct FlowCalcFlow FlowCalcFlow;

/*
 * Called when a new packet arrives.
 */
typedef KLException * (*FlowCalcPacketNewFun)(
    FlowCalcFlow *flow, const KLListNode *cur_node, int timer_index,
    int ack, void *flow_set_client_data);

typedef struct FlowCalcSetDef {
    CalcDef calc_spec;
    KLBufferedOutput *result_log; /* Write results here */
    KLBufferedOutput *sample_log; /* Write unfiltered results here */
    int no_convert_addresses;     /* Don't convert addresses to names */
    int qualify_host_names;       /* Qualify host names with domains */
    FlowCalcPacketNewFun packet_new;
    void *client_data;
} FlowCalcSetDef;

KLException *
flow_calc_set_packet_new(
    DPCapFlow *flow, const KLListNode *cur_node, int timer_index,
    int ack, void *flow_set_client_data);

void
flow_calc_set_flow_new(DPCapFlow *flow, void *flow_set_client_data);

void
flow_calc_set_flow_delete(DPCapFlow *flow, void *flow_set_client_data);

FlowCalcSet *
flow_calc_set_new(FlowCalcSetDef *def);

void
flow_calc_set_verify(void *client_data);

void
flow_calc_set_delete(FlowCalcSet *flow_calc_set);

KLException *
flow_calc_update_output(KLBufferedOutput *bo, void *client_data);

int
flow_calc_get_metrics(
    FlowCalcFlow *flow, int from_index, int to_index,
    const char **metric_name, FilterResult *result);

#endif
