/*
 * $Id: lbc_tailgate_packet.h,v 1.2 2001/06/28 03:16:50 laik Exp $
 *
 * This file contains information necessary to use the link bandwidth
 * calculation routines in tailgate mode.
 *
 * Copyright (C) 1998 Kevin Lai
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __LBC_TAILGATE_PACKET_H__
#define __LBC_TAILGATE_PACKET_H__

#include "dpcap_flow.h"

struct LBCTailgatePacket;
typedef struct LBCTailgatePacket LBCTailgatePacket;

struct LBCTailgatePacketGroup;
typedef struct LBCTailgatePacketGroup LBCTailgatePacketGroup;

typedef struct LBCTailgatePacketGroupDef {
    unsigned int num_packets;
    unsigned int num_tailgated_packets;
    unsigned short packet_id;
    unsigned short ttl;                   /* Time-to-live */
    unsigned int tailgater_size;
} LBCTailgatePacketGroupDef;

LBCTailgatePacketGroup *
lbc_tailgate_packet_group_new(LBCTailgatePacketGroupDef *def);

void
lbc_tailgate_packet_group_free(LBCTailgatePacketGroup *pg);

int
lbc_tailgate_packet_group_match(
    LBCTailgatePacketGroup *pg, unsigned short packet_id);

void
lbc_tailgate_packet_group_new_sample(
    LBCTailgatePacketGroup *pg, const DPCapFlowPacket *dpcap_packet, 
    unsigned short packet_id, const struct timespec *delay);

int
lbc_tailgate_packet_group_check_finished(LBCTailgatePacketGroup *pg);

const struct in_addr *
lbc_tailgate_packet_group_get_addr(LBCTailgatePacketGroup *pg);

unsigned int 
lbc_tailgate_packet_group_get_ttl(LBCTailgatePacketGroup *pg);

void
lbc_tailgate_packet_group_get_packet_size(
    LBCTailgatePacketGroup *pg, unsigned int *ack_size, 
    unsigned int *tailgater_size);

void
lbc_tailgate_packet_group_get_delay(
    LBCTailgatePacketGroup *pg, struct timespec *delay);


const DPCapFlowPacket *
lbc_tailgate_packet_group_get_packet(LBCTailgatePacketGroup *pg);

#endif


